@@ -1,7 +1,6 @@
+import six
 from datetime import datetime, date, time
 from decimal import Decimal
-from operator import itemgetter
-import six
 
 from django import forms
 from django.contrib import admin, messages
@@ -29,7 +28,7 @@ NUMERIC_WIDGET = forms.TextInput(attrs={'size': 10})
 INTEGER_LIKE = (fields.IntegerField, {'widget': NUMERIC_WIDGET})
 STRING_LIKE = (fields.CharField, {
     'widget': forms.Textarea(attrs={'rows': 3}),
-#    'required': False,
+    #'required': False,
 })
 
 FIELDS = {
@@ -43,6 +42,10 @@ FIELDS = {
     float: (fields.FloatField, {'widget': NUMERIC_WIDGET}),
 }
 
+if six.PY3:
+    unicode = str
+    long = int
+
 if not six.PY3:
     FIELDS.update({
         long: INTEGER_LIKE,
@@ -53,7 +56,7 @@ if not six.PY3:
 class ConstanceForm(forms.Form):
     def __init__(self, *args, **kwargs):
         super(ConstanceForm, self).__init__(*args, **kwargs)
-        for name, opts in settings.CONFIG.iteritems():
+        for name, opts in six.iteritems(settings.CONFIG):
             _type = type(opts['default'])
             field_class, kwargs = FIELDS[_type]
             if _type in (str, unicode) and opts.get('required', True) is False:
@@ -71,7 +74,9 @@ class ConstanceAdmin(admin.ModelAdmin):
 
     def get_urls(self):
         info = self.model._meta.app_label, self.model._meta.module_name
-        return patterns('',
+        return patterns(
+            '',
+
             url(r'^$',
                 self.admin_site.admin_view(self.changelist_view),
                 name='%s_%s_changelist' % info),
@@ -86,10 +91,9 @@ class ConstanceAdmin(admin.ModelAdmin):
         if not self.has_change_permission(request, None):
             raise PermissionDenied
         default_initial = ((name, opts['default'])
-                           for name, opts in settings.CONFIG.iteritems())
+                           for name, opts in six.iteritems(settings.CONFIG))
         # Then update the mapping with actually values from the backend
-        initial = dict(default_initial,
-            **dict(config._backend.mget(settings.CONFIG.keys())))
+        initial = dict(default_initial, **dict(config._backend.mget(settings.CONFIG.keys())))
         form = ConstanceForm(initial=initial)
         if request.method == 'POST':
             form = ConstanceForm(request.POST)
@@ -111,7 +115,7 @@ class ConstanceAdmin(admin.ModelAdmin):
             'media': self.media + form.media,
             'readonly': settings.READONLY,
         }
-        for name, opts in settings.CONFIG.iteritems():
+        for name, opts in six.iteritems(settings.CONFIG):
             default = opts['default']
             help_text = opts['help_text']
             # First try to load the value from the actual backend
